@@ -1,7 +1,5 @@
-from pyg_base import cell, is_strs, is_date, ulist, logger, tree_update, cell_clear, dt, as_list, get_DAG, descendants, add_edge, del_edge, eq
-from pyg_base import cell_item, cell_inputs, Dict
-
-from pyg_base import get_GAD, get_DAG, get_cache
+from pyg_base import cell, is_date, ulist, logger, cell_clear, as_list, get_DAG, get_GAD, get_cache, descendants
+from pyg_base import cell_item, Dict
 from pyg_mongo._q import _id, _deleted
 from pyg_mongo._table import mongo_table
 from functools import partial
@@ -220,8 +218,7 @@ class db_cell(cell):
         if self.get(_db) is None: 
             return super(db_cell, self)._clear()
         else:
-            return self[[_db] + self.db().pk]
-
+            return self[[_db, _updated] + self.db().pk] if _updated in self else self[[_db] + self.db().pk]
 
     def save(self):
         if self.get(_db) is None:
